aboutsummaryrefslogtreecommitdiff
path: root/sound/mididrv.cpp
diff options
context:
space:
mode:
authorFlorian Kagerer2010-06-25 20:51:57 +0000
committerFlorian Kagerer2010-06-25 20:51:57 +0000
commitc35e3505319977e56d1c413b39133dfedf6c1105 (patch)
tree9bdc8bd3f602b347d56dd221132b14d1ce8ecc34 /sound/mididrv.cpp
parent683d54a74660745d6bd408788170b19adb08581e (diff)
downloadscummvm-rg350-c35e3505319977e56d1c413b39133dfedf6c1105.tar.gz
scummvm-rg350-c35e3505319977e56d1c413b39133dfedf6c1105.tar.bz2
scummvm-rg350-c35e3505319977e56d1c413b39133dfedf6c1105.zip
AUDIO: get rid of MDT_PREFER_MIDI since it should be sufficient to either select MDT_PREFER_MT32 or MDT_PREFER_GM
svn-id: r50288
Diffstat (limited to 'sound/mididrv.cpp')
-rw-r--r--sound/mididrv.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/sound/mididrv.cpp b/sound/mididrv.cpp
index 0fa64e8b03..80c8ae9c22 100644
--- a/sound/mididrv.cpp
+++ b/sound/mididrv.cpp
@@ -177,9 +177,9 @@ MidiDriver::DeviceHandle MidiDriver::detectDevice(int flags) {
// If the selected driver did not match the flags setting,
// we try to determine a suitable and "optimal" music driver.
const MusicPlugin::List p = MusicMan.getPlugins();
// If only MDT_MIDI but not MDT_PREFER_MIDI is set we prefer the other devices (which will always be
// detected since they are hard coded and cannot be disabled.
- for (int l = (flags & MDT_PREFER_MIDI) ? 1 : 0; l < 2; l++) {
+ for (int l = (flags & (MDT_PREFER_GM | MDT_PREFER_MT32)) ? 1 : 0; l < 2; l++) {
if ((flags & MDT_MIDI) && (l == 1)) {
// If a preferred MT32 or GM device has been selected that device gets returned
hdl = getDeviceHandle(ConfMan.get((flags & MDT_PREFER_MT32) ? "mt32_device" : ((flags & MDT_PREFER_GM) ? "gm_device" : "auto"), Common::ConfigManager::kApplicationDomain));
@@ -177,9 +177,9 @@ MidiDriver::DeviceHandle MidiDriver::detectDevice(int flags) {
// we try to determine a suitable and "optimal" music driver.
const MusicPlugin::List p = MusicMan.getPlugins();
- // If only MDT_MIDI but not MDT_PREFER_MIDI is set we prefer the other devices (which will always be
+ // If only MDT_MIDI but not MDT_PREFER_MT32 or MDT_PREFER_GM is set we prefer the other devices (which will always be
// detected since they are hard coded and cannot be disabled.